@@ -52,7 +52,7 @@ QTerminalApp * QTerminalApp::m_instance = NULL;
 
 void print_usage_and_exit(int code)
 {
-    printf("QTerminal %s\n", STR_VERSION);
+    printf("QTerminal %s\n", QTERMINAL_VERSION);
     puts("Usage: qterminal [OPTION]...\n");
     puts("  -d,  --drop               Start in \"dropdown mode\" (like Yakuake or Tilda)");
     puts("  -e,  --execute <command>  Execute command instead of shell");
@@ -67,7 +67,7 @@ void print_usage_and_exit(int code)
 
 void print_version_and_exit(int code=0)
 {
-    printf("%s\n", STR_VERSION);
+    printf("%s\n", QTERMINAL_VERSION);
     exit(code);
 }
 
@@ -81,29 +81,32 @@ void parse_args(int argc, char* argv[], QString& workdir, QString & shell_comman
         {
             case 'h':
                 print_usage_and_exit(0);
+                break;
             case 'w':
-                workdir = QString(optarg);
+                workdir = QString::fromLocal8Bit(optarg);
                 break;
             case 'e':
-                shell_command = QString(optarg);
+                shell_command = QString::fromLocal8Bit(optarg);
                 // #15 "Raw" -e params
                 // Passing "raw" params (like konsole -e mcedit /tmp/tmp.txt") is more preferable - then I can call QString("qterminal -e ") + cmd_line in other programs
                 while (optind < argc)
                 {
                     //printf("arg: %d - %s\n", optind, argv[optind]);
-                    shell_command += ' ' + QString(argv[optind++]);
+                    shell_command += QLatin1Char(' ') + QString::fromLocal8Bit(argv[optind++]);
                 }
                 break;
             case 'd':
                 dropMode = true;
                 break;
             case 'p':
-                Properties::Instance(QString(optarg));
+                Properties::Instance(QString::fromLocal8Bit(optarg));
                 break;
             case '?':
                 print_usage_and_exit(1);
+                break;
             case 'v':
                 print_version_and_exit();
+                break;
         }
     }
     while(next_option != -1);
@@ -111,9 +114,9 @@ void parse_args(int argc, char* argv[], QString& workdir, QString & shell_comman
 
 int main(int argc, char *argv[])
 {
-    QApplication::setApplicationName("qterminal");
-    QApplication::setApplicationVersion(STR_VERSION);
-    QApplication::setOrganizationDomain("qterminal.org");
+    QApplication::setApplicationName(QStringLiteral("qterminal"));
+    QApplication::setApplicationVersion(QStringLiteral(QTERMINAL_VERSION));
+    QApplication::setOrganizationDomain(QStringLiteral("qterminal.org"));
 #if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     QApplication::setDesktopFileName(QLatin1String("qterminal.desktop"));
 #endif
@@ -141,7 +144,7 @@ int main(int argc, char *argv[])
     const QSettings settings;
     const QFileInfo customStyle = QFileInfo(
         QFileInfo(settings.fileName()).canonicalPath() +
-        "/style.qss"
+        QStringLiteral("/style.qss")
     );
     if (customStyle.isFile() && customStyle.isReadable())
     {
@@ -155,14 +158,14 @@ int main(int argc, char *argv[])
     /* setup our custom icon theme if there is no system theme (OS X, Windows) */
     QCoreApplication::instance()->setAttribute(Qt::AA_UseHighDpiPixmaps); //Fix for High-DPI systems
     if (QIcon::themeName().isEmpty())
-        QIcon::setThemeName("QTerminal");
+        QIcon::setThemeName(QStringLiteral("QTerminal"));
 
     // translations
-    QString fname = QString("qterminal_%1.qm").arg(QLocale::system().name().left(5));
+    QString fname = QString::fromLatin1("qterminal_%1.qm").arg(QLocale::system().name().left(5));
     QTranslator translator;
 #ifdef TRANSLATIONS_DIR
     qDebug() << "TRANSLATIONS_DIR: Loading translation file" << fname << "from dir" << TRANSLATIONS_DIR;
-    qDebug() << "load success:" << translator.load(fname, TRANSLATIONS_DIR, "_");
+    qDebug() << "load success:" << translator.load(fname, QString::fromUtf8(TRANSLATIONS_DIR), QStringLiteral("_"));
 #endif
 #ifdef APPLE_BUNDLE
     qDebug() << "APPLE_BUNDLE: Loading translator file" << fname << "from dir" << QApplication::applicationDirPath()+"../translations";
@@ -193,6 +196,8 @@ MainWindow *QTerminalApp::newWindow(bool dropMode, TerminalConfig &cfg)
     else
     {
         window = new MainWindow(cfg, dropMode);
+        if (Properties::Instance()->windowMaximized)
+            window->setWindowState(Qt::WindowMaximized);
         window->show();
     }
     return window;
@@ -264,7 +269,7 @@ void QTerminalApp::registerOnDbus()
         return;
     }
     new ProcessAdaptor(this);
-    QDBusConnection::sessionBus().registerObject("/", this);
+    QDBusConnection::sessionBus().registerObject(QStringLiteral("/"), this);
 }
 
 QList<QDBusObjectPath> QTerminalApp::getWindows()
