@@ -36,229 +36,284 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="324"/>
+        <location filename="../mainwindow.cpp" line="337"/>
         <source>&amp;Close Tab</source>
         <translation>タブを閉じる(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="180"/>
+        <location filename="../mainwindow.cpp" line="239"/>
         <source>Split Terminal &amp;Horizontally</source>
         <translation>ターミナルの上下分割(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="187"/>
+        <location filename="../mainwindow.cpp" line="212"/>
+        <source>&amp;Clear Active Terminal</source>
+        <translation>アクティブなターミナルをクリアする(&amp;C)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="242"/>
         <source>Split Terminal &amp;Vertically</source>
         <translation>ターミナルの左右分割(&amp;V)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="194"/>
+        <location filename="../mainwindow.cpp" line="247"/>
         <source>&amp;Collapse Subterminal</source>
         <translation>サブターミナルを折りたたむ(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="201"/>
-        <source>N&amp;ext Subterminal</source>
-        <translation>次のサブターミナル(&amp;E)</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="208"/>
-        <source>P&amp;revious Subterminal</source>
-        <translation>前のサブターミナル(&amp;R)</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="150"/>
+        <location filename="../mainwindow.cpp" line="219"/>
         <source>&amp;Next Tab</source>
         <translation>次のタブ(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="157"/>
+        <location filename="../mainwindow.cpp" line="222"/>
         <source>&amp;Previous Tab</source>
         <translation>前のタブ(&amp;P)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="164"/>
+        <location filename="../mainwindow.cpp" line="225"/>
+        <source>&amp;Previous Tab in History</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="228"/>
+        <source>&amp;Next Tab in History</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="231"/>
         <source>Move Tab &amp;Left</source>
         <translation>タブを左へ移動(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="234"/>
         <source>Move Tab &amp;Right</source>
         <translation>タブを右へ移動(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="218"/>
+        <location filename="../mainwindow.cpp" line="250"/>
+        <source>&amp;Top Subterminal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="253"/>
+        <source>&amp;Bottom Subterminal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="256"/>
+        <source>L&amp;eft Subterminal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="259"/>
+        <source>R&amp;ight Subterminal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="266"/>
         <source>Copy &amp;Selection</source>
         <translation>選択部分をコピー(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="232"/>
+        <location filename="../mainwindow.cpp" line="272"/>
         <source>Paste S&amp;election</source>
         <translation>選択部分を貼り付け(&amp;E)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="274"/>
+        <location filename="../mainwindow.cpp" line="294"/>
         <source>&amp;Save Session</source>
         <translation>セッションを保存(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="280"/>
+        <location filename="../mainwindow.cpp" line="300"/>
         <source>&amp;Load Session</source>
         <translation>セッションを読出(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="313"/>
+        <location filename="../mainwindow.cpp" line="312"/>
+        <source>Rename session</source>
+        <translation>セッション名の変更</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="324"/>
         <source>New Tab From &amp;Preset</source>
         <translation>新規タブをプリセットで開く(&amp;P)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="314"/>
+        <location filename="../mainwindow.cpp" line="325"/>
         <source>1 &amp;Terminal</source>
         <translation>画面分割なし(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="316"/>
+        <location filename="../mainwindow.cpp" line="327"/>
         <source>2 &amp;Horizontal Terminals</source>
         <translation>上下２分割(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="318"/>
+        <location filename="../mainwindow.cpp" line="329"/>
         <source>2 &amp;Vertical Terminals</source>
         <translation>左右２分割(&amp;V)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="320"/>
+        <location filename="../mainwindow.cpp" line="331"/>
         <source>4 Terminal&amp;s</source>
         <translation>４分割(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="412"/>
+        <location filename="../mainwindow.cpp" line="345"/>
+        <source>&amp;Preferences...</source>
+        <translation>設定(&amp;P)...</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="349"/>
+        <source>&amp;Quit</source>
+        <translation>終了(&amp;Q)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="380"/>
+        <source>Toggle Bookmarks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="388"/>
         <source>&amp;Bottom</source>
         <translation>下(&amp;B)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="413"/>
+        <location filename="../mainwindow.cpp" line="389"/>
         <source>&amp;Top</source>
         <translation>上(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="414"/>
-        <location filename="../mainwindow.cpp" line="445"/>
+        <location filename="../mainwindow.cpp" line="390"/>
+        <location filename="../mainwindow.cpp" line="426"/>
         <source>&amp;Right</source>
         <translation>右(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="415"/>
-        <location filename="../mainwindow.cpp" line="446"/>
+        <location filename="../mainwindow.cpp" line="391"/>
+        <location filename="../mainwindow.cpp" line="427"/>
         <source>&amp;Left</source>
         <translation>左(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="430"/>
+        <location filename="../mainwindow.cpp" line="409"/>
         <source>&amp;Tabs Layout</source>
         <translation>タブの位置(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="444"/>
+        <location filename="../mainwindow.cpp" line="425"/>
         <source>&amp;None</source>
         <translation>なし(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="462"/>
+        <location filename="../mainwindow.cpp" line="443"/>
         <source>S&amp;crollbar Layout</source>
         <translation>スクロールバーの位置(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="529"/>
+        <location filename="../mainwindow.cpp" line="456"/>
+        <source>&amp;BlockCursor</source>
+        <translation>ブロックカーソル(&amp;B)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="457"/>
+        <source>&amp;UnderlineCursor</source>
+        <translation>アンダーラインカーソル(&amp;U)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="458"/>
+        <source>&amp;IBeamCursor</source>
+        <translation>アイビームカーソル(&amp;I)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="475"/>
+        <source>&amp;Keyboard Cursor Shape</source>
+        <translation>カーソルの形(&amp;K)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="566"/>
         <source>Exit QTerminal</source>
         <translation>QTerminal終了</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="531"/>
+        <location filename="../mainwindow.cpp" line="568"/>
         <source>Do not ask again</source>
         <translation>次から確認しない</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="538"/>
+        <location filename="../mainwindow.cpp" line="576"/>
         <source>Are you sure you want to exit?</source>
         <translation>終了してもよろしいですか?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="559"/>
+        <location filename="../mainwindow.cpp" line="607"/>
         <source>A lightweight multiplatform terminal emulator</source>
         <translation>軽量マルチプラットフォーム ターミナルエミュレータ</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="53"/>
+        <location filename="../mainwindow.cpp" line="79"/>
         <source>Bookmarks</source>
         <translation>ブックマーク</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="97"/>
-        <source>Rename Session</source>
-        <translation>タブ名の変更</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="130"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Press &quot;%1&quot; to see the terminal.</source>
         <translation>&quot;%1&quot;を押すとそのターミナルを見ることができます</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="141"/>
-        <source>&amp;Clear Current Tab</source>
-        <translation>現在のタブをクリア(&amp;C)</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="225"/>
+        <location filename="../mainwindow.cpp" line="269"/>
         <source>Paste Clip&amp;board</source>
         <translation>クリップボードの貼り付け(&amp;B)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="239"/>
+        <location filename="../mainwindow.cpp" line="275"/>
         <source>Zoom &amp;in</source>
         <translation>ズームイン(&amp;I)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="246"/>
+        <location filename="../mainwindow.cpp" line="278"/>
         <source>Zoom &amp;out</source>
         <translation>ズームアウト(&amp;O)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="253"/>
+        <location filename="../mainwindow.cpp" line="281"/>
         <source>Zoom rese&amp;t</source>
         <translation>ズームリセット(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="262"/>
+        <location filename="../mainwindow.cpp" line="286"/>
         <source>&amp;Find...</source>
         <translation>検索(&amp;F)...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="287"/>
+        <location filename="../mainwindow.cpp" line="307"/>
         <source>&amp;Toggle Menu</source>
         <translation>メニューの表示/非表示(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="306"/>
+        <location filename="../mainwindow.cpp" line="320"/>
         <source>&amp;New Tab</source>
         <translation>新規タブ(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="331"/>
+        <location filename="../mainwindow.cpp" line="340"/>
         <source>&amp;New Window</source>
         <translation>新規ウィンドウ(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="365"/>
+        <location filename="../mainwindow.cpp" line="355"/>
         <source>&amp;Hide Window Borders</source>
         <translation>ウィンドウ枠を隠す(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="380"/>
+        <location filename="../mainwindow.cpp" line="366"/>
         <source>&amp;Show Tab Bar</source>
         <translation>タブを表示(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="392"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>Fullscreen</source>
         <translation>フルスクリーン</translation>
     </message>
@@ -266,7 +321,7 @@
 <context>
     <name>PropertiesDialog</name>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="319"/>
+        <location filename="../forms/propertiesdialog.ui" line="449"/>
         <source>Emulation</source>
         <translation>エミュレーション</translation>
     </message>
@@ -287,7 +342,7 @@
     </message>
     <message>
         <location filename="../forms/propertiesdialog.ui" line="57"/>
-        <location filename="../forms/propertiesdialog.ui" line="344"/>
+        <location filename="../forms/propertiesdialog.ui" line="474"/>
         <source>Behavior</source>
         <translation>挙動</translation>
     </message>
@@ -297,12 +352,12 @@
         <translation>ドロップダウン</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="90"/>
+        <location filename="../forms/propertiesdialog.ui" line="100"/>
         <source>Color scheme</source>
         <translation>配色</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="100"/>
+        <location filename="../forms/propertiesdialog.ui" line="296"/>
         <source>Widget style</source>
         <translation>ウィジェットのスタイル</translation>
     </message>
@@ -312,144 +367,205 @@
         <translation>スクロールバーの位置</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="120"/>
+        <location filename="../forms/propertiesdialog.ui" line="267"/>
         <source>Tabs position</source>
         <translation>タブの位置</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="130"/>
+        <location filename="../forms/propertiesdialog.ui" line="319"/>
         <source>Show the menu bar</source>
         <translation>メニューバーの表示</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="144"/>
+        <location filename="../forms/propertiesdialog.ui" line="136"/>
         <source>Show a border around the current terminal</source>
         <translation>カレントターミナルの境界を表示</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="151"/>
+        <location filename="../forms/propertiesdialog.ui" line="153"/>
         <source>Application transparency</source>
         <translation>アプリケーションの透過</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="161"/>
+        <location filename="../forms/propertiesdialog.ui" line="143"/>
         <source>Terminal transparency</source>
         <translation>ターミナルの透過</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="184"/>
+        <location filename="../forms/propertiesdialog.ui" line="120"/>
         <source>Start with preset:</source>
-        <translation>プリセットでスタート</translation>
+        <translation>プリセットでスタート:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="208"/>
+        <location filename="../forms/propertiesdialog.ui" line="164"/>
         <source>None (single terminal)</source>
         <translation>画面分割なし</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="212"/>
+        <location filename="../forms/propertiesdialog.ui" line="169"/>
         <source>2 terminals horizontally</source>
         <translation>上下２分割</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="217"/>
+        <location filename="../forms/propertiesdialog.ui" line="174"/>
         <source>2 terminals vertically</source>
         <translation>左右２分割</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="223"/>
+        <location filename="../forms/propertiesdialog.ui" line="179"/>
         <source>4 terminals</source>
         <translation>４分割</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="259"/>
+        <location filename="../forms/propertiesdialog.ui" line="218"/>
         <source>Font</source>
         <translation>フォント</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="328"/>
+        <location filename="../forms/propertiesdialog.ui" line="336"/>
+        <source>Change window title based on current terminal</source>
+        <translation>現在のターミナルのウィンドウタイトルの変更</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="343"/>
+        <source>Change window icon based on current terminal</source>
+        <translation>現在のターミナルのアイコンの変更</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="350"/>
+        <source>Enable bi-directional text support</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="357"/>
+        <source>Background image:</source>
+        <translation>背景画像:</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="369"/>
+        <source>Select</source>
+        <translation>選択</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="378"/>
+        <source>Show terminal size on resize</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="395"/>
+        <location filename="../forms/propertiesdialog.ui" line="425"/>
+        <source>px</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="405"/>
+        <source>Show close button on each tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="415"/>
+        <source>Terminal margin</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="458"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;エミュレータの挙動の選択。注意して頂きたいのは、この選択はオペレーティングシステムと適合する必要はありません。&lt;/p&gt;&lt;p&gt; &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt;エミュレーションは最小の機能にフォールバックしたものです。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="350"/>
+        <location filename="../forms/propertiesdialog.ui" line="480"/>
         <source>Action after paste</source>
         <translation>貼り付け後の挙動</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="383"/>
+        <location filename="../forms/propertiesdialog.ui" line="490"/>
+        <source>Confirm multiline paste</source>
+        <translation>複数にまたがる行の貼り付けの確認</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="497"/>
+        <source>Trim trailing newlines in pasted text</source>
+        <translation>テキストの貼付け時に空白の行を生成しない</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="530"/>
         <source>Open new terminals in current working directory</source>
         <translation>カレントディレクトリに新しいターミナルを開く</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="390"/>
+        <location filename="../forms/propertiesdialog.ui" line="537"/>
         <source>Save Size when closing</source>
         <translation>閉じるときにサイズを保存する</translation>
     </message>
-        <message>
-        <location filename="../forms/propertiesdialog.ui" line="397"/>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="544"/>
         <source>Save Position when closing</source>
         <translation>閉じるときに位置を保存する</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="404"/>
+        <location filename="../forms/propertiesdialog.ui" line="551"/>
         <source>Ask for confirmation when closing</source>
         <translation>閉じるときに確認する</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="414"/>
+        <location filename="../forms/propertiesdialog.ui" line="561"/>
         <source>Unlimited history</source>
         <translation>履歴を制限しない</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="421"/>
+        <location filename="../forms/propertiesdialog.ui" line="568"/>
         <source>History size (in lines)</source>
         <translation>履歴 (行数)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="472"/>
+        <location filename="../forms/propertiesdialog.ui" line="575"/>
+        <source>Default $TERM</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="666"/>
         <source>Height</source>
         <translation>高さ</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="479"/>
-        <location filename="../forms/propertiesdialog.ui" line="493"/>
+        <location filename="../forms/propertiesdialog.ui" line="676"/>
+        <location filename="../forms/propertiesdialog.ui" line="693"/>
         <source>%</source>
         <translation>%</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="486"/>
+        <location filename="../forms/propertiesdialog.ui" line="683"/>
         <source>Width</source>
         <translation>幅</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="536"/>
+        <location filename="../forms/propertiesdialog.ui" line="739"/>
         <source>Edit bookmark file contents</source>
         <translation>ブックマークの内容を編集する</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="558"/>
+        <location filename="../forms/propertiesdialog.ui" line="761"/>
         <source>Enable bookmarks</source>
         <translation>ブックマークを利用可能にする</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="567"/>
+        <location filename="../forms/propertiesdialog.ui" line="770"/>
         <source>Bookmark file</source>
         <translation>ブックマークファイル</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="168"/>
-        <location filename="../forms/propertiesdialog.ui" line="191"/>
+        <location filename="../forms/propertiesdialog.ui" line="187"/>
+        <location filename="../forms/propertiesdialog.ui" line="280"/>
         <source> %</source>
         <translation>%</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="437"/>
+        <location filename="../forms/propertiesdialog.ui" line="631"/>
         <source>Shortcut</source>
         <translation>ショートカット</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="442"/>
+        <location filename="../forms/propertiesdialog.ui" line="636"/>
         <source>Key</source>
         <translation>キー割当</translation>
     </message>
@@ -459,103 +575,146 @@
         <translation>ブックマーク</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="137"/>
+        <location filename="../forms/propertiesdialog.ui" line="90"/>
         <source>Hide tab bar with only one tab</source>
         <translation>1つのタブしか使用していない場合、タブバーを隠す</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="289"/>
+        <location filename="../forms/propertiesdialog.ui" line="254"/>
         <source>&amp;Change...</source>
         <translation>変更（&amp;C)...</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="454"/>
+        <location filename="../forms/propertiesdialog.ui" line="326"/>
+        <source>Cursor shape</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="385"/>
+        <source>Fixed tab width:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="648"/>
         <source>Show on start</source>
         <translation>起動時に表示します</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="461"/>
+        <location filename="../forms/propertiesdialog.ui" line="655"/>
         <source>Size</source>
         <translation>サイズ</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="507"/>
+        <location filename="../forms/propertiesdialog.ui" line="707"/>
         <source>Shortcut:</source>
         <translation>ショートカット:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="577"/>
+        <location filename="../forms/propertiesdialog.ui" line="783"/>
         <source>Find...</source>
         <translation>検索...</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="586"/>
+        <location filename="../forms/propertiesdialog.ui" line="792"/>
         <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
         <translation>ブックマークファイルの場所を指定することができます。OwnCloudやDropboxのようなツールとブックマークを共有することが容易にできます。</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="45"/>
+        <location filename="../propertiesdialog.cpp" line="101"/>
         <source>No scrollbar</source>
         <translation>スクロールバーなし</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="45"/>
-        <location filename="../propertiesdialog.cpp" line="51"/>
+        <location filename="../propertiesdialog.cpp" line="101"/>
+        <location filename="../propertiesdialog.cpp" line="107"/>
         <source>Left</source>
         <translation>左</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="45"/>
-        <location filename="../propertiesdialog.cpp" line="51"/>
+        <location filename="../propertiesdialog.cpp" line="101"/>
+        <location filename="../propertiesdialog.cpp" line="107"/>
         <source>Right</source>
         <translation>右</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="51"/>
+        <location filename="../propertiesdialog.cpp" line="107"/>
         <source>Top</source>
         <translation>上</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="51"/>
+        <location filename="../propertiesdialog.cpp" line="107"/>
         <source>Bottom</source>
         <translation>下</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="63"/>
+        <location filename="../propertiesdialog.cpp" line="118"/>
+        <source>BlockCursor</source>
+        <translation>ブロックカーソル</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="118"/>
+        <source>UnderlineCursor</source>
+        <translation>アンダーラインカーソル</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="118"/>
+        <source>IBeamCursor</source>
+        <translation>アイビームカーソル</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="130"/>
         <source>No move</source>
         <translation type="unfinished">無動作</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="63"/>
+        <location filename="../propertiesdialog.cpp" line="130"/>
         <source>Move start</source>
         <translation type="unfinished">動作開始</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="63"/>
+        <location filename="../propertiesdialog.cpp" line="130"/>
         <source>Move end</source>
         <translation type="unfinished">動作終了</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="68"/>
-        <location filename="../propertiesdialog.cpp" line="122"/>
+        <location filename="../propertiesdialog.cpp" line="135"/>
+        <location filename="../propertiesdialog.cpp" line="209"/>
         <source>System Default</source>
         <translation>システムの既定</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="252"/>
+        <location filename="../propertiesdialog.cpp" line="293"/>
+        <source>Choose a background image</source>
+        <translation>背景画像を選択</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="294"/>
+        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
+        <translation>画像 (*.bmp *.png *.xpm *.jpg)</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="359"/>
         <source>Open or create bookmarks file</source>
         <translation>ブックマークファイルを開く、または新規作成</translation>
     </message>
 </context>
+<context>
+    <name>QMessageBox</name>
+    <message>
+        <location filename="../termwidget.cpp" line="238"/>
+        <source>Show Details...</source>
+        <translation>詳細を表示...</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../bookmarkswidget.cpp" line="97"/>
+        <location filename="../bookmarkswidget.cpp" line="110"/>
         <source>Local Bookmarks</source>
         <translation>ローカルブックマーク</translation>
     </message>
     <message>
-        <location filename="../bookmarkswidget.cpp" line="187"/>
+        <location filename="../bookmarkswidget.cpp" line="168"/>
         <source>Synchronized Bookmarks</source>
         <translation>ブックマークの同期</translation>
     </message>
@@ -563,96 +722,104 @@
 <context>
     <name>TabWidget</name>
     <message>
-        <location filename="../tabwidget.cpp" line="70"/>
-        <location filename="../tabwidget.cpp" line="175"/>
+        <location filename="../tabwidget.cpp" line="78"/>
+        <location filename="../tabwidget.cpp" line="224"/>
         <source>Shell No. %1</source>
         <translation>Shell No. %1</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="160"/>
+        <location filename="../tabwidget.cpp" line="192"/>
         <source>Tab name</source>
         <translation>タブの名前</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="161"/>
+        <location filename="../tabwidget.cpp" line="193"/>
         <source>New tab name:</source>
         <translation>タブの新しい名前:</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="183"/>
+        <location filename="../tabwidget.cpp" line="213"/>
+        <source>Select new tab title color</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../tabwidget.cpp" line="234"/>
         <source>Close session</source>
         <translation>タブを閉じる</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="185"/>
-        <source>Rename session</source>
-        <translation>タブ名の変更</translation>
+        <location filename="../tabwidget.cpp" line="236"/>
+        <source>Change title color</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>TermWidgetHolder</name>
     <message>
-        <location filename="../termwidgetholder.cpp" line="46"/>
+        <location filename="../termwidgetholder.cpp" line="78"/>
         <source>Load Session</source>
         <translation>セッションの読込</translation>
     </message>
     <message>
-        <location filename="../termwidgetholder.cpp" line="47"/>
+        <location filename="../termwidgetholder.cpp" line="79"/>
         <source>List of saved sessions:</source>
         <translation>保存されたセッションリスト:</translation>
     </message>
 </context>
+<context>
+    <name>TermWidgetImpl</name>
+    <message>
+        <location filename="../termwidget.cpp" line="230"/>
+        <source>Paste multiline text</source>
+        <translation>複数行のテキストを貼り付け</translation>
+    </message>
+    <message>
+        <location filename="../termwidget.cpp" line="231"/>
+        <source>Are you sure you want to paste this text?</source>
+        <translation>テキストを貼り付けますか?</translation>
+    </message>
+</context>
 <context>
     <name>mainWindow</name>
     <message>
-        <location filename="../forms/qterminal.ui" line="76"/>
+        <location filename="../forms/qterminal.ui" line="67"/>
         <source>&amp;Actions</source>
         <translation>操作(&amp;A)</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="81"/>
+        <location filename="../forms/qterminal.ui" line="72"/>
         <source>&amp;Help</source>
         <translation>ヘルプ(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="93"/>
+        <location filename="../forms/qterminal.ui" line="84"/>
         <source>&amp;Edit</source>
         <translation>編集(&amp;E)</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="109"/>
+        <location filename="../forms/qterminal.ui" line="100"/>
         <source>&amp;About...</source>
         <translation>QTerminalについて(&amp;A)...</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="114"/>
+        <location filename="../forms/qterminal.ui" line="105"/>
         <source>About &amp;Qt...</source>
         <translation>Qtについて(&amp;Q)...</translation>
     </message>
-    <message>
-        <location filename="../forms/qterminal.ui" line="119"/>
-        <source>&amp;Preferences...</source>
-        <translation>設定(&amp;P)...</translation>
-    </message>
     <message>
         <location filename="../forms/qterminal.ui" line="14"/>
         <source>MainWindow</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="68"/>
+        <location filename="../forms/qterminal.ui" line="59"/>
         <source>&amp;File</source>
         <translation>ファイル(&amp;F)</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="88"/>
+        <location filename="../forms/qterminal.ui" line="79"/>
         <source>&amp;View</source>
         <translation>表示(&amp;V)</translation>
     </message>
-    <message>
-        <location filename="../forms/qterminal.ui" line="129"/>
-        <source>&amp;Quit</source>
-        <translation>終了(&amp;Q)</translation>
-    </message>
 </context>
 </TS>
