@@ -36,229 +36,284 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="324"/>
+        <location filename="../mainwindow.cpp" line="337"/>
         <source>&amp;Close Tab</source>
         <translation>关闭标签页(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="180"/>
+        <location filename="../mainwindow.cpp" line="239"/>
         <source>Split Terminal &amp;Horizontally</source>
         <translation>水平布局终端(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="187"/>
+        <location filename="../mainwindow.cpp" line="212"/>
+        <source>&amp;Clear Active Terminal</source>
+        <translation>清空活动终端(&amp;C)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="242"/>
         <source>Split Terminal &amp;Vertically</source>
         <translation>垂直布局终端(&amp;V)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="194"/>
+        <location filename="../mainwindow.cpp" line="247"/>
         <source>&amp;Collapse Subterminal</source>
-        <translation>折叠布局终端(&amp;C)</translation>
+        <translation>折叠布局子终端(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="201"/>
-        <source>N&amp;ext Subterminal</source>
-        <translation>弹出终端(&amp;E)</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="208"/>
-        <source>P&amp;revious Subterminal</source>
-        <translation>上个终端(&amp;R)</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="150"/>
+        <location filename="../mainwindow.cpp" line="219"/>
         <source>&amp;Next Tab</source>
         <translation>下个标签页(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="157"/>
+        <location filename="../mainwindow.cpp" line="222"/>
         <source>&amp;Previous Tab</source>
         <translation>最前终端页(&amp;P)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="164"/>
+        <location filename="../mainwindow.cpp" line="225"/>
+        <source>&amp;Previous Tab in History</source>
+        <translation>历史中的前一个选项卡(&amp;P)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="228"/>
+        <source>&amp;Next Tab in History</source>
+        <translation>历史中的下一个选项卡(&amp;N)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="231"/>
         <source>Move Tab &amp;Left</source>
         <translation>往左边移动标签页(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="../mainwindow.cpp" line="234"/>
         <source>Move Tab &amp;Right</source>
         <translation>往右边移动标签页(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="218"/>
+        <location filename="../mainwindow.cpp" line="250"/>
+        <source>&amp;Top Subterminal</source>
+        <translation>顶部子终端(&amp;T)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="253"/>
+        <source>&amp;Bottom Subterminal</source>
+        <translation>底部子终端(&amp;B)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="256"/>
+        <source>L&amp;eft Subterminal</source>
+        <translation>左部子终端(&amp;E)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="259"/>
+        <source>R&amp;ight Subterminal</source>
+        <translation>右部子终端(&amp;I)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="266"/>
         <source>Copy &amp;Selection</source>
         <translation>复制选区(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="232"/>
+        <location filename="../mainwindow.cpp" line="272"/>
         <source>Paste S&amp;election</source>
         <translation>粘贴选区(&amp;E)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="274"/>
+        <location filename="../mainwindow.cpp" line="294"/>
         <source>&amp;Save Session</source>
         <translation>保存会话(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="280"/>
+        <location filename="../mainwindow.cpp" line="300"/>
         <source>&amp;Load Session</source>
         <translation>载入会话(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="313"/>
-        <source>New Tab From &amp;Preset</source>
-        <translation>新标签窗口く(&amp;P)</translation>
+        <location filename="../mainwindow.cpp" line="312"/>
+        <source>Rename session</source>
+        <translation>重命名会话</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="314"/>
+        <location filename="../mainwindow.cpp" line="324"/>
+        <source>New Tab From &amp;Preset</source>
+        <translation>新标签窗口(&amp;P)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="325"/>
         <source>1 &amp;Terminal</source>
         <translation>单个终端窗口(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="316"/>
+        <location filename="../mainwindow.cpp" line="327"/>
         <source>2 &amp;Horizontal Terminals</source>
         <translation>水平分割为2(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="318"/>
+        <location filename="../mainwindow.cpp" line="329"/>
         <source>2 &amp;Vertical Terminals</source>
         <translation>垂直分割为2(&amp;V)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="320"/>
+        <location filename="../mainwindow.cpp" line="331"/>
         <source>4 Terminal&amp;s</source>
         <translation>分割4块(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="412"/>
+        <location filename="../mainwindow.cpp" line="345"/>
+        <source>&amp;Preferences...</source>
+        <translation>参数配置(&amp;P)...</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="349"/>
+        <source>&amp;Quit</source>
+        <translation>退出(&amp;Q)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="380"/>
+        <source>Toggle Bookmarks</source>
+        <translation>切换书签</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="388"/>
         <source>&amp;Bottom</source>
         <translation>下(&amp;B)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="413"/>
+        <location filename="../mainwindow.cpp" line="389"/>
         <source>&amp;Top</source>
         <translation>上(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="414"/>
-        <location filename="../mainwindow.cpp" line="445"/>
+        <location filename="../mainwindow.cpp" line="390"/>
+        <location filename="../mainwindow.cpp" line="426"/>
         <source>&amp;Right</source>
         <translation>右(&amp;R)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="415"/>
-        <location filename="../mainwindow.cpp" line="446"/>
+        <location filename="../mainwindow.cpp" line="391"/>
+        <location filename="../mainwindow.cpp" line="427"/>
         <source>&amp;Left</source>
         <translation>左(&amp;L)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="430"/>
+        <location filename="../mainwindow.cpp" line="409"/>
         <source>&amp;Tabs Layout</source>
         <translation>标签位置(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="444"/>
+        <location filename="../mainwindow.cpp" line="425"/>
         <source>&amp;None</source>
         <translation>空(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="462"/>
+        <location filename="../mainwindow.cpp" line="443"/>
         <source>S&amp;crollbar Layout</source>
         <translation>滚动条位置(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="529"/>
+        <location filename="../mainwindow.cpp" line="456"/>
+        <source>&amp;BlockCursor</source>
+        <translation>块状光标(&amp;B)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="457"/>
+        <source>&amp;UnderlineCursor</source>
+        <translation>下划线状光标(&amp;U)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="458"/>
+        <source>&amp;IBeamCursor</source>
+        <translation>条状光标(&amp;I)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="475"/>
+        <source>&amp;Keyboard Cursor Shape</source>
+        <translation>光标样式(&amp;K)</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="566"/>
         <source>Exit QTerminal</source>
         <translation>退出程序</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="531"/>
+        <location filename="../mainwindow.cpp" line="568"/>
         <source>Do not ask again</source>
         <translation>不要再次问我</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="538"/>
+        <location filename="../mainwindow.cpp" line="576"/>
         <source>Are you sure you want to exit?</source>
         <translation>您真的要关闭本程序吗?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="559"/>
+        <location filename="../mainwindow.cpp" line="607"/>
         <source>A lightweight multiplatform terminal emulator</source>
         <translation>轻量级多平台支持的终端模拟器</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="53"/>
+        <location filename="../mainwindow.cpp" line="79"/>
         <source>Bookmarks</source>
         <translation>书签</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="97"/>
-        <source>Rename Session</source>
-        <translation>重命名会话</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="130"/>
+        <location filename="../mainwindow.cpp" line="171"/>
         <source>Press &quot;%1&quot; to see the terminal.</source>
-        <translation>按下&quot;%1&quot;显示该终端</translation>
+        <translation>按下&quot;%1&quot;显示该终端。</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="141"/>
-        <source>&amp;Clear Current Tab</source>
-        <translation>清理当前标签(&amp;C)</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="225"/>
+        <location filename="../mainwindow.cpp" line="269"/>
         <source>Paste Clip&amp;board</source>
         <translation>粘贴剪切板内容(&amp;B)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="239"/>
+        <location filename="../mainwindow.cpp" line="275"/>
         <source>Zoom &amp;in</source>
         <translation>缩小(&amp;I)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="246"/>
+        <location filename="../mainwindow.cpp" line="278"/>
         <source>Zoom &amp;out</source>
         <translation>放大(&amp;O)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="253"/>
+        <location filename="../mainwindow.cpp" line="281"/>
         <source>Zoom rese&amp;t</source>
         <translation>重置大小(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="262"/>
+        <location filename="../mainwindow.cpp" line="286"/>
         <source>&amp;Find...</source>
         <translation>搜索(&amp;F)...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="287"/>
+        <location filename="../mainwindow.cpp" line="307"/>
         <source>&amp;Toggle Menu</source>
         <translation>下拉菜单(&amp;T)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="306"/>
+        <location filename="../mainwindow.cpp" line="320"/>
         <source>&amp;New Tab</source>
         <translation>新建标签页(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="331"/>
+        <location filename="../mainwindow.cpp" line="340"/>
         <source>&amp;New Window</source>
         <translation>新建窗口(&amp;N)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="365"/>
+        <location filename="../mainwindow.cpp" line="355"/>
         <source>&amp;Hide Window Borders</source>
         <translation>隐藏窗口边框(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="380"/>
+        <location filename="../mainwindow.cpp" line="366"/>
         <source>&amp;Show Tab Bar</source>
         <translation>显示标签栏(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="392"/>
+        <location filename="../mainwindow.cpp" line="374"/>
         <source>Fullscreen</source>
         <translation>全屏显示</translation>
     </message>
@@ -266,7 +321,7 @@
 <context>
     <name>PropertiesDialog</name>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="319"/>
+        <location filename="../forms/propertiesdialog.ui" line="449"/>
         <source>Emulation</source>
         <translation>模拟器</translation>
     </message>
@@ -287,7 +342,7 @@
     </message>
     <message>
         <location filename="../forms/propertiesdialog.ui" line="57"/>
-        <location filename="../forms/propertiesdialog.ui" line="344"/>
+        <location filename="../forms/propertiesdialog.ui" line="474"/>
         <source>Behavior</source>
         <translation>行为</translation>
     </message>
@@ -297,12 +352,12 @@
         <translation>下拉菜单</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="90"/>
+        <location filename="../forms/propertiesdialog.ui" line="100"/>
         <source>Color scheme</source>
         <translation>终端颜色</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="100"/>
+        <location filename="../forms/propertiesdialog.ui" line="296"/>
         <source>Widget style</source>
         <translation>控件样式</translation>
     </message>
@@ -312,144 +367,205 @@
         <translation>滚动栏位置</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="120"/>
+        <location filename="../forms/propertiesdialog.ui" line="267"/>
         <source>Tabs position</source>
         <translation>标签页位置</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="130"/>
+        <location filename="../forms/propertiesdialog.ui" line="319"/>
         <source>Show the menu bar</source>
         <translation>显示菜单栏</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="144"/>
+        <location filename="../forms/propertiesdialog.ui" line="136"/>
         <source>Show a border around the current terminal</source>
-        <translation type="unfinished">显示当前终端周围的边框</translation>
+        <translation>显示当前终端周围的边框</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="151"/>
+        <location filename="../forms/propertiesdialog.ui" line="153"/>
         <source>Application transparency</source>
         <translation>透明设置</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="161"/>
+        <location filename="../forms/propertiesdialog.ui" line="143"/>
         <source>Terminal transparency</source>
         <translation>终端透明度</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="184"/>
+        <location filename="../forms/propertiesdialog.ui" line="120"/>
         <source>Start with preset:</source>
-        <translation type="unfinished">默认配置</translation>
+        <translation>默认配置:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="208"/>
+        <location filename="../forms/propertiesdialog.ui" line="164"/>
         <source>None (single terminal)</source>
         <translation>为空或者单终端模式</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="212"/>
+        <location filename="../forms/propertiesdialog.ui" line="169"/>
         <source>2 terminals horizontally</source>
         <translation>水平分割为2块</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="217"/>
+        <location filename="../forms/propertiesdialog.ui" line="174"/>
         <source>2 terminals vertically</source>
         <translation>垂直分割为2块</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="223"/>
+        <location filename="../forms/propertiesdialog.ui" line="179"/>
         <source>4 terminals</source>
         <translation>４分割为4块</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="259"/>
+        <location filename="../forms/propertiesdialog.ui" line="218"/>
         <source>Font</source>
         <translation>字体</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="328"/>
-        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;终端行为: 注意! 它可能不适合您的操作系统. &lt;/p&gt;&lt;p&gt; &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt;模拟器可能回退到一个最基础的功能模式。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+        <location filename="../forms/propertiesdialog.ui" line="336"/>
+        <source>Change window title based on current terminal</source>
+        <translation>基于当前终端更改窗口标题</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="343"/>
+        <source>Change window icon based on current terminal</source>
+        <translation>基于当前终端更改窗口图标</translation>
     </message>
     <message>
         <location filename="../forms/propertiesdialog.ui" line="350"/>
+        <source>Enable bi-directional text support</source>
+        <translation>开启双目录文本支持</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="357"/>
+        <source>Background image:</source>
+        <translation>背景图像:</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="369"/>
+        <source>Select</source>
+        <translation>选择</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="378"/>
+        <source>Show terminal size on resize</source>
+        <translation>重新调整大小时显示终端大小</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="395"/>
+        <location filename="../forms/propertiesdialog.ui" line="425"/>
+        <source>px</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="405"/>
+        <source>Show close button on each tab</source>
+        <translation>在每个标签上显示关闭按钮</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="415"/>
+        <source>Terminal margin</source>
+        <translation>终端边距</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="458"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;The &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation is a fallback with a minimal featureset.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;选择模拟模式。注意它不必符合您的操作系统。&lt;/p&gt;&lt;p&gt;选择 &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; 模拟模式会回退到最基础的功能模式。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="480"/>
         <source>Action after paste</source>
-        <translation type="unfinished">粘贴之后的动作</translation>
+        <translation>粘贴之后的动作</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="383"/>
+        <location filename="../forms/propertiesdialog.ui" line="490"/>
+        <source>Confirm multiline paste</source>
+        <translation>确认多行粘贴</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="497"/>
+        <source>Trim trailing newlines in pasted text</source>
+        <translation>修剪粘贴文本的最后空白行</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="530"/>
         <source>Open new terminals in current working directory</source>
-        <translation type="unfinished">在当前工作路径打开新的终端</translation>
+        <translation>在当前工作路径打开新的终端</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="390"/>
+        <location filename="../forms/propertiesdialog.ui" line="537"/>
         <source>Save Size when closing</source>
-        <translation type="unfinished">关闭时保存窗口尺寸</translation>
+        <translation>关闭时保存窗口尺寸</translation>
     </message>
-        <message>
-        <location filename="../forms/propertiesdialog.ui" line="397"/>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="544"/>
         <source>Save Position when closing</source>
-        <translation type="unfinished">关闭时保存窗口位置</translation>
+        <translation>关闭时保存窗口位置</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="404"/>
+        <location filename="../forms/propertiesdialog.ui" line="551"/>
         <source>Ask for confirmation when closing</source>
-        <translation type="unfinished">关闭窗口需要确认</translation>
+        <translation>关闭窗口需要确认</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="414"/>
+        <location filename="../forms/propertiesdialog.ui" line="561"/>
         <source>Unlimited history</source>
-        <translation type="unfinished">不限制历史记录条数</translation>
+        <translation>不限制历史记录条数</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="421"/>
+        <location filename="../forms/propertiesdialog.ui" line="568"/>
         <source>History size (in lines)</source>
         <translation>历史记录大小 (行数)</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="472"/>
+        <location filename="../forms/propertiesdialog.ui" line="575"/>
+        <source>Default $TERM</source>
+        <translation>默认 $TERM</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="666"/>
         <source>Height</source>
         <translation>高度</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="479"/>
-        <location filename="../forms/propertiesdialog.ui" line="493"/>
+        <location filename="../forms/propertiesdialog.ui" line="676"/>
+        <location filename="../forms/propertiesdialog.ui" line="693"/>
         <source>%</source>
-        <translation>%</translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="486"/>
+        <location filename="../forms/propertiesdialog.ui" line="683"/>
         <source>Width</source>
-        <translation type="unfinished">宽度</translation>
+        <translation>宽度</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="536"/>
+        <location filename="../forms/propertiesdialog.ui" line="739"/>
         <source>Edit bookmark file contents</source>
         <translation>编辑书签文件内容</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="558"/>
+        <location filename="../forms/propertiesdialog.ui" line="761"/>
         <source>Enable bookmarks</source>
-        <translation type="unfinished">启用书签功能</translation>
+        <translation>启用书签功能</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="567"/>
+        <location filename="../forms/propertiesdialog.ui" line="770"/>
         <source>Bookmark file</source>
         <translation>书签文件</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="168"/>
-        <location filename="../forms/propertiesdialog.ui" line="191"/>
+        <location filename="../forms/propertiesdialog.ui" line="187"/>
+        <location filename="../forms/propertiesdialog.ui" line="280"/>
         <source> %</source>
-        <translation>%</translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="437"/>
+        <location filename="../forms/propertiesdialog.ui" line="631"/>
         <source>Shortcut</source>
         <translation>快捷键</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="442"/>
+        <location filename="../forms/propertiesdialog.ui" line="636"/>
         <source>Key</source>
         <translation>按键</translation>
     </message>
@@ -459,103 +575,146 @@
         <translation>书签</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="137"/>
+        <location filename="../forms/propertiesdialog.ui" line="90"/>
         <source>Hide tab bar with only one tab</source>
-        <translation type="unfinished">标签栏只显示一个页面</translation>
+        <translation>只有一个页面时隐藏标签栏</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="289"/>
+        <location filename="../forms/propertiesdialog.ui" line="254"/>
         <source>&amp;Change...</source>
-        <translation type="unfinished">修改设置（&amp;C)...</translation>
+        <translation>修改设置(&amp;C)...</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="454"/>
+        <location filename="../forms/propertiesdialog.ui" line="326"/>
+        <source>Cursor shape</source>
+        <translation>光标形状</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="385"/>
+        <source>Fixed tab width:</source>
+        <translation>固定的选项卡宽度：</translation>
+    </message>
+    <message>
+        <location filename="../forms/propertiesdialog.ui" line="648"/>
         <source>Show on start</source>
         <translation>启动时显示</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="461"/>
+        <location filename="../forms/propertiesdialog.ui" line="655"/>
         <source>Size</source>
         <translation>尺寸</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="507"/>
+        <location filename="../forms/propertiesdialog.ui" line="707"/>
         <source>Shortcut:</source>
         <translation>快捷键:</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="577"/>
+        <location filename="../forms/propertiesdialog.ui" line="783"/>
         <source>Find...</source>
         <translation>搜索...</translation>
     </message>
     <message>
-        <location filename="../forms/propertiesdialog.ui" line="586"/>
+        <location filename="../forms/propertiesdialog.ui" line="792"/>
         <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
-        <translation type="unfinished">您可以指定书签保存位置, 它可以很容易通过私有云或者Dropbox分享。</translation>
+        <translation>您可以指定书签保存位置，它很容易通过私有云或者Dropbox分享。</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="45"/>
+        <location filename="../propertiesdialog.cpp" line="101"/>
         <source>No scrollbar</source>
         <translation>无滚动栏</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="45"/>
-        <location filename="../propertiesdialog.cpp" line="51"/>
+        <location filename="../propertiesdialog.cpp" line="101"/>
+        <location filename="../propertiesdialog.cpp" line="107"/>
         <source>Left</source>
         <translation>左</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="45"/>
-        <location filename="../propertiesdialog.cpp" line="51"/>
+        <location filename="../propertiesdialog.cpp" line="101"/>
+        <location filename="../propertiesdialog.cpp" line="107"/>
         <source>Right</source>
         <translation>右</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="51"/>
+        <location filename="../propertiesdialog.cpp" line="107"/>
         <source>Top</source>
         <translation>上</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="51"/>
+        <location filename="../propertiesdialog.cpp" line="107"/>
         <source>Bottom</source>
         <translation>下</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="63"/>
+        <location filename="../propertiesdialog.cpp" line="118"/>
+        <source>BlockCursor</source>
+        <translation>块状光标</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="118"/>
+        <source>UnderlineCursor</source>
+        <translation>下划线状光标</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="118"/>
+        <source>IBeamCursor</source>
+        <translation>条状光标</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="130"/>
         <source>No move</source>
         <translation>无动作</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="63"/>
+        <location filename="../propertiesdialog.cpp" line="130"/>
         <source>Move start</source>
         <translation>开始移动</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="63"/>
+        <location filename="../propertiesdialog.cpp" line="130"/>
         <source>Move end</source>
         <translation>移动完成</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="68"/>
-        <location filename="../propertiesdialog.cpp" line="122"/>
+        <location filename="../propertiesdialog.cpp" line="135"/>
+        <location filename="../propertiesdialog.cpp" line="209"/>
         <source>System Default</source>
         <translation>系统默认</translation>
     </message>
     <message>
-        <location filename="../propertiesdialog.cpp" line="252"/>
+        <location filename="../propertiesdialog.cpp" line="293"/>
+        <source>Choose a background image</source>
+        <translation>选择背景图片</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="294"/>
+        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
+        <translation>图像 (*.bmp *.png *.xpm *.jpg)</translation>
+    </message>
+    <message>
+        <location filename="../propertiesdialog.cpp" line="359"/>
         <source>Open or create bookmarks file</source>
         <translation>打开或者创建书签文件</translation>
     </message>
 </context>
+<context>
+    <name>QMessageBox</name>
+    <message>
+        <location filename="../termwidget.cpp" line="238"/>
+        <source>Show Details...</source>
+        <translation>显示详细信息...</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../bookmarkswidget.cpp" line="97"/>
+        <location filename="../bookmarkswidget.cpp" line="110"/>
         <source>Local Bookmarks</source>
         <translation>本地书签</translation>
     </message>
     <message>
-        <location filename="../bookmarkswidget.cpp" line="187"/>
+        <location filename="../bookmarkswidget.cpp" line="168"/>
         <source>Synchronized Bookmarks</source>
         <translation>书签同步</translation>
     </message>
@@ -563,96 +722,104 @@
 <context>
     <name>TabWidget</name>
     <message>
-        <location filename="../tabwidget.cpp" line="70"/>
-        <location filename="../tabwidget.cpp" line="175"/>
+        <location filename="../tabwidget.cpp" line="78"/>
+        <location filename="../tabwidget.cpp" line="224"/>
         <source>Shell No. %1</source>
         <translation>Shell No. %1</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="160"/>
+        <location filename="../tabwidget.cpp" line="192"/>
         <source>Tab name</source>
         <translation>标签名</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="161"/>
+        <location filename="../tabwidget.cpp" line="193"/>
         <source>New tab name:</source>
         <translation>新的标签名:</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="183"/>
+        <location filename="../tabwidget.cpp" line="213"/>
+        <source>Select new tab title color</source>
+        <translation>选择新的标签标题颜色</translation>
+    </message>
+    <message>
+        <location filename="../tabwidget.cpp" line="234"/>
         <source>Close session</source>
         <translation>关闭会话</translation>
     </message>
     <message>
-        <location filename="../tabwidget.cpp" line="185"/>
-        <source>Rename session</source>
-        <translation>重命名会话</translation>
+        <location filename="../tabwidget.cpp" line="236"/>
+        <source>Change title color</source>
+        <translation>更改标题颜色</translation>
     </message>
 </context>
 <context>
     <name>TermWidgetHolder</name>
     <message>
-        <location filename="../termwidgetholder.cpp" line="46"/>
+        <location filename="../termwidgetholder.cpp" line="78"/>
         <source>Load Session</source>
         <translation>载入会话</translation>
     </message>
     <message>
-        <location filename="../termwidgetholder.cpp" line="47"/>
+        <location filename="../termwidgetholder.cpp" line="79"/>
         <source>List of saved sessions:</source>
         <translation>列出保存的会话:</translation>
     </message>
 </context>
+<context>
+    <name>TermWidgetImpl</name>
+    <message>
+        <location filename="../termwidget.cpp" line="230"/>
+        <source>Paste multiline text</source>
+        <translation>粘贴多行文本</translation>
+    </message>
+    <message>
+        <location filename="../termwidget.cpp" line="231"/>
+        <source>Are you sure you want to paste this text?</source>
+        <translation>是否确认粘贴此文本？</translation>
+    </message>
+</context>
 <context>
     <name>mainWindow</name>
     <message>
-        <location filename="../forms/qterminal.ui" line="76"/>
+        <location filename="../forms/qterminal.ui" line="67"/>
         <source>&amp;Actions</source>
         <translation>动作(&amp;A)</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="81"/>
+        <location filename="../forms/qterminal.ui" line="72"/>
         <source>&amp;Help</source>
         <translation>帮助(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="93"/>
+        <location filename="../forms/qterminal.ui" line="84"/>
         <source>&amp;Edit</source>
         <translation>编辑(&amp;E)</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="109"/>
+        <location filename="../forms/qterminal.ui" line="100"/>
         <source>&amp;About...</source>
         <translation>关于本程序(&amp;A)...</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="114"/>
+        <location filename="../forms/qterminal.ui" line="105"/>
         <source>About &amp;Qt...</source>
         <translation>关于Qt(&amp;Q)...</translation>
     </message>
-    <message>
-        <location filename="../forms/qterminal.ui" line="119"/>
-        <source>&amp;Preferences...</source>
-        <translation type="unfinished">参数配置(&amp;P)...</translation>
-    </message>
     <message>
         <location filename="../forms/qterminal.ui" line="14"/>
         <source>MainWindow</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="68"/>
+        <location filename="../forms/qterminal.ui" line="59"/>
         <source>&amp;File</source>
         <translation>文件(&amp;F)</translation>
     </message>
     <message>
-        <location filename="../forms/qterminal.ui" line="88"/>
+        <location filename="../forms/qterminal.ui" line="79"/>
         <source>&amp;View</source>
         <translation>查看(&amp;V)</translation>
     </message>
-    <message>
-        <location filename="../forms/qterminal.ui" line="129"/>
-        <source>&amp;Quit</source>
-        <translation>退出(&amp;Q)</translation>
-    </message>
 </context>
 </TS>
